from fractions import Fraction
from math import sqrt
from re import split as re_split
from sys import stderr

def extract_square(n):
    # return the largest d such that d^2 divides n
    answer = 1
    for p in range(2,n):
        if p*p > n: return answer
        while n%(p*p) == 0:
            n //= p*p
            answer *= p
        if n%p == 0:
            n //= p
    return answer

def gcd(a, b):
    a, b = abs(a), abs(b)
    assert (a, b) != (0, 0)
    while b: a, b = b, a%b
    return a

def sgn(x):
    if x < 0: return -1
    if x > 0: return +1
    return 0

def normalize(a, b1, b2, c):
    b2 *= abs(b1)**2
    b1 = sgn(b1)
    if c < 0: a, b1, c = -a, -b1, -c
    s = extract_square(b2)
    d = gcd( gcd(a,c), s )
    return a//d, b1*s//d, b2//(s*s), c//d

def is_leq(x, a, b1, b2, c):
    # returns whether x <= (a + b1*sqrt(b2)) / c
    # assumes (a, b1, b2, c) is normalized
    lhs = c*x - a
    if sgn(lhs) < sgn(b1): return True
    if sgn(lhs) > sgn(b1): return False
    if sgn(lhs) == 0: return True
    if sgn(lhs) == +1: return lhs**2 <= b1*b1*b2
    if sgn(lhs) == -1: return lhs**2 >= b1*b1*b2

def is_eq(x, a, b1, b2, c):
    lhs = c*x - a
    return (sgn(lhs) == sgn(b1)) and lhs**2 == b1*b1*b2

def find_floor(a, b1, b2, c):
    xlo, xhi = -(2**60), 2**60
    assert     is_leq(xlo, a, b1, b2, c)
    assert not is_leq(xhi, a, b1, b2, c)
    while xhi - xlo > 1:
        xmed = (xlo + xhi) // 2
        if is_leq(xmed, a, b1, b2, c):
            xlo = xmed
        else:
            xhi = xmed
    return xlo

def linear_function_to_finite_continued_fraction(qa,qb):
    print('linear_function_to_finite_continued_fraction',qa,qb, file=stderr)
    output = []
    num, den = -qb, qa
    while True:
        d = gcd(num,den)
        num, den = num//d, den//d
        if den < 0: num, den = -num, -den
        output.append( num // den )
        if num % den == 0: break
        num, den = den, num - (num//den)*den
    return output, []

def quadratic_equation_to_periodic_continued_fraction(qa,qb,qc,k):
    qd = qb*qb - 4*qa*qc
    if k == 1: assert qd >= 0
    if k == 2: assert qd > 0

    a, b1, b2, c = -qb, -1, qd, 2*qa
    if k == 2: a, b1, b2, c = -qb, +1, qd, 2*qa

    print('initial sol pre normalize = ( {} + {}*sqrt({}) ) / {}'.format(a,b1,b2,c), file=stderr)
    a, b1, b2, c = normalize(a, b1, b2, c)
    print('initial sol post normalize = ( {} + {}*sqrt({}) ) / {}'.format(a,b1,b2,c), file=stderr)

    if b2 == 0:
        print('switching from quadratic to linear', file=stderr)
        return linear_function_to_finite_continued_fraction(c,-a)
    if b2 == 1:
        print('switching from quadratic to linear', file=stderr)
        return linear_function_to_finite_continued_fraction(c,-a-b1)

    output = []
    history = [ (a, b1, b2, c) ]
    history_set = set(history)
    while True:
        if len(history) % 1000 == 0: print('history len', len(history), file=stderr )
        # print('current parameters:',a,b1,b2,c, file=stderr )
        # print('rough value',(a+b1*sqrt(b2))/c)
        next_val = find_floor(a, b1, b2, c)
        output.append(next_val)
        if is_eq(next_val, a, b1, b2, c):
            return output,[]
        a, b1, b2, c = c*(a-c*next_val), -b1*c, b2, (a-c*next_val)**2 - b1*b1*b2
        # print('new parameters pre-normalization:',a,b1,b2,c)
        a, b1, b2, c = normalize(a, b1, b2, c)
        if (a, b1, b2, c) in history_set:
            i = history.index( (a, b1, b2, c) )
            return output[:i], output[i:]
        history.append( (a, b1, b2, c) )
        history_set.add( (a, b1, b2, c) )

def preperiod_period_to_fraction(preperiod,period):
    total = Fraction( preperiod[0] )    
    current_term = Fraction(-2)
    for a in preperiod[1:]:
        current_term = -current_term / 2**a
        total += current_term
    if period != []:
        first_loop_sum = Fraction(0)
        loop_multiplier = Fraction(1)
        for a in period:
            current_term = -current_term / 2**a
            first_loop_sum += current_term
            loop_multiplier *= -1
            loop_multiplier /= 2**a
        total += first_loop_sum / (1 - loop_multiplier)
    return total

# main ---------------------------------------------------------------------------

T = int( input() )
for t in range(T):
    print('TEST',t, file=stderr)
    input()
    poly, k = input().split()
    print('poly', poly, 'k', k, file=stderr)
    poly = re_split( r'[*]x.*?(?=[+-])', poly )
    poly = [ int(x) for x in poly ]
    k = int(k)
    print('parsed poly',poly,k, file=stderr)
    if len(poly) == 2:
        preperiod, period = linear_function_to_finite_continued_fraction(*poly)
    else:
        preperiod, period = quadratic_equation_to_periodic_continued_fraction(*poly,k)
    print('preperiod', preperiod, 'period', period, file=stderr )
    total = preperiod_period_to_fraction( preperiod, period )
    print('{}*x-{} 1'.format(total.denominator,total.numerator))


